==> react-calendar-2.4.0.tgz: package/src/CenturyView/Decades.jsx <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';

import Flex from '../Flex';
import Decade from './Decade';

import {
  getBeginOfDecade,
  getBeginOfCenturyYear,
} from '../shared/dates';
import { getTileActivityFlags } from '../shared/utils';
import { isClassName, isMaxDate, isMinDate, isValue } from '../shared/propTypes';

export default class Decades extends Component {
  get start() {
    const { activeStartDate } = this.props;
    return getBeginOfCenturyYear(activeStartDate);
  }

  get end() {
    return this.start + 99;
  }

  render() {
    const { end, start } = this;
    const {
      maxDate, minDate, onClick, tileClassName, tileContent, value, valueType,
    } = this.props;

    const decadeProps = {
      maxDate,
      minDate,
      onClick,
      tileClassName,
      tileContent,
    };

    const decades = [];
    for (let decade = start; decade <= end; decade += 10) {
      const date = getBeginOfDecade(decade);

      decades.push(
        <Decade
          {...getTileActivityFlags(value, valueType, date, 'decade')}
          date={date}
          decade={decade}
          key={decade}
          {...decadeProps}
        />,
      );
    }

    return (
      <Flex
        className="react-calendar__century-view__decades"
        count={3}
        wrap
      >
        {decades}
      </Flex>
    );
  }
}

Decades.propTypes = {
  activeStartDate: PropTypes.instanceOf(Date).isRequired,
  maxDate: isMaxDate,
  minDate: isMinDate,
  onClick: PropTypes.func,
  tileClassName: isClassName,
  tileContent: PropTypes.oneOfType([
    PropTypes.func,
    PropTypes.node,
  ]),
  value: isValue,
  valueType: PropTypes.string,
};

==> react-calendar-2.7.0.tgz: package/src/CenturyView/Decades.jsx <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';

import Flex from '../Flex';
import Decade from './Decade';

import {
  getBeginOfDecade,
  getBeginOfCenturyYear,
} from '../shared/dates';
import { getTileActivityFlags } from '../shared/utils';
import { isClassName, isMaxDate, isMinDate, isValue } from '../shared/propTypes';

export default class Decades extends Component {
  get start() {
    const { activeStartDate } = this.props;
    return getBeginOfCenturyYear(activeStartDate);
  }

  get end() {
    return this.start + 99;
  }

  render() {
    const { end, start } = this;
    const {
      maxDate, minDate, onClick, tileClassName, tileContent, value, valueType,
    } = this.props;

    const decadeProps = {
      maxDate,
      minDate,
      onClick,
      tileClassName,
      tileContent,
    };

    const decades = [];
    for (let decade = start; decade <= end; decade += 10) {
      const date = getBeginOfDecade(decade);

      decades.push(
        <Decade
          {...getTileActivityFlags(value, valueType, date, 'decade')}
          date={date}
          decade={decade}
          key={decade}
          {...decadeProps}
        />,
      );
    }

    return (
      <Flex
        className="react-calendar__century-view__decades"
        count={3}
        wrap
      >
        {decades}
      </Flex>
    );
  }
}

Decades.propTypes = {
  activeStartDate: PropTypes.instanceOf(Date).isRequired,
  maxDate: isMaxDate,
  minDate: isMinDate,
  onClick: PropTypes.func,
  tileClassName: PropTypes.oneOfType([
    PropTypes.func,
    isClassName,
  ]),
  tileContent: PropTypes.oneOfType([
    PropTypes.func,
    PropTypes.node,
  ]),
  value: isValue,
  valueType: PropTypes.string,
};
